BreakpointLocationsArguments class

Arguments for breakpointLocations request.

Inheritance

Constructors

BreakpointLocationsArguments({int? column, int? endColumn, int? endLine, required int line, required Source source})
BreakpointLocationsArguments.fromMap(Map<String, Object?> obj)

Properties

column → int?
Start position within line to search possible breakpoint locations in. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based. If no column is given, the first position in the start line is assumed.
final
endColumn → int?
End position within endLine to search possible breakpoint locations in. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based. If no end column is given, the last position in the end line is assumed.
final
endLine → int?
End line of range to search possible breakpoint locations in. If no end line is given, then the end line is assumed to be the start line.
final
hashCode → int
The hash code for this object.
no setterinherited
line → int
Start line of range to search possible breakpoint locations in. If only the line is specified, the request returns all possible locations in that line.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source
The source location of the breakpoints; either source.path or source.sourceReference must be specified.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → BreakpointLocationsArguments