BreakpointMode class

A BreakpointMode is provided as a option when setting breakpoints on sources or instructions.

Constructors

BreakpointMode({required List<BreakpointModeApplicability> appliesTo, String? description, required String label, required String mode})
BreakpointMode.fromMap(Map<String, Object?> obj)

Properties

appliesTo → List<BreakpointModeApplicability>
Describes one or more type of breakpoint this mode applies to.
final
description → String?
A help text providing additional information about the breakpoint mode. This string is typically shown as a hover and can be translated.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
The name of the breakpoint mode. This is shown in the UI.
final
mode → String
The internal ID of the mode. This value is passed to the setBreakpoints request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → BreakpointMode