ByteStreamServerChannel class

A wrapper over a Stream/StreamSink that encodes/decores DAP/LSP request/response/event messages.

Constructors

ByteStreamServerChannel(Stream<List<int>> _input, StreamSink<List<int>> _output, Logger? _logger)

Properties

closed → Future
Future that will be completed when the input stream is closed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
listen(void onMessage(ProtocolMessage message), {Function? onError, void onDone()?}) → StreamSubscription<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEvent(Event event) → void
sendRequest(Request request) → void
sendResponse(Response response) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited