Capabilities class

Information about the capabilities of a debug adapter.

Constructors

Capabilities({List<ColumnDescriptor>? additionalModuleColumns, List<BreakpointMode>? breakpointModes, List<String>? completionTriggerCharacters, List<ExceptionBreakpointsFilter>? exceptionBreakpointFilters, bool? supportSuspendDebuggee, bool? supportTerminateDebuggee, List<String>? supportedChecksumAlgorithms, bool? supportsANSIStyling, bool? supportsBreakpointLocationsRequest, bool? supportsCancelRequest, bool? supportsClipboardContext, bool? supportsCompletionsRequest, bool? supportsConditionalBreakpoints, bool? supportsConfigurationDoneRequest, bool? supportsDataBreakpointBytes, bool? supportsDataBreakpoints, bool? supportsDelayedStackTraceLoading, bool? supportsDisassembleRequest, bool? supportsEvaluateForHovers, bool? supportsExceptionFilterOptions, bool? supportsExceptionInfoRequest, bool? supportsExceptionOptions, bool? supportsFunctionBreakpoints, bool? supportsGotoTargetsRequest, bool? supportsHitConditionalBreakpoints, bool? supportsInstructionBreakpoints, bool? supportsLoadedSourcesRequest, bool? supportsLogPoints, bool? supportsModulesRequest, bool? supportsReadMemoryRequest, bool? supportsRestartFrame, bool? supportsRestartRequest, bool? supportsSetExpression, bool? supportsSetVariable, bool? supportsSingleThreadExecutionRequests, bool? supportsStepBack, bool? supportsStepInTargetsRequest, bool? supportsSteppingGranularity, bool? supportsTerminateRequest, bool? supportsTerminateThreadsRequest, bool? supportsValueFormattingOptions, bool? supportsWriteMemoryRequest})
Capabilities.fromMap(Map<String, Object?> obj)

Properties

additionalModuleColumns → List<ColumnDescriptor>?
The set of additional module information exposed by the debug adapter.
final
breakpointModes → List<BreakpointMode>?
Modes of breakpoints supported by the debug adapter, such as 'hardware' or 'software'. If present, the client may allow the user to select a mode and include it in its setBreakpoints request.
final
completionTriggerCharacters → List<String>?
The set of characters that should trigger completion in a REPL. If not specified, the UI should assume the . character.
final
exceptionBreakpointFilters → List<ExceptionBreakpointsFilter>?
Available exception filter options for the setExceptionBreakpoints request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedChecksumAlgorithms → List<String>?
Checksum algorithms supported by the debug adapter.
final
supportsANSIStyling → bool?
The debug adapter supports ANSI escape sequences in styling of OutputEvent.output and Variable.value fields.
final
supportsBreakpointLocationsRequest → bool?
The debug adapter supports the breakpointLocations request.
final
supportsCancelRequest → bool?
The debug adapter supports the cancel request.
final
supportsClipboardContext → bool?
The debug adapter supports the clipboard context value in the evaluate request.
final
supportsCompletionsRequest → bool?
The debug adapter supports the completions request.
final
supportsConditionalBreakpoints → bool?
The debug adapter supports conditional breakpoints.
final
supportsConfigurationDoneRequest → bool?
The debug adapter supports the configurationDone request.
final
supportsDataBreakpointBytes → bool?
The debug adapter supports the asAddress and bytes fields in the dataBreakpointInfo request.
final
supportsDataBreakpoints → bool?
The debug adapter supports data breakpoints.
final
supportsDelayedStackTraceLoading → bool?
The debug adapter supports the delayed loading of parts of the stack, which requires that both the startFrame and levels arguments and the totalFrames result of the stackTrace request are supported.
final
supportsDisassembleRequest → bool?
The debug adapter supports the disassemble request.
final
supportsEvaluateForHovers → bool?
The debug adapter supports a (side effect free) evaluate request for data hovers.
final
supportsExceptionFilterOptions → bool?
The debug adapter supports filterOptions as an argument on the setExceptionBreakpoints request.
final
supportsExceptionInfoRequest → bool?
The debug adapter supports the exceptionInfo request.
final
supportsExceptionOptions → bool?
The debug adapter supports exceptionOptions on the setExceptionBreakpoints request.
final
supportsFunctionBreakpoints → bool?
The debug adapter supports function breakpoints.
final
supportsGotoTargetsRequest → bool?
The debug adapter supports the gotoTargets request.
final
supportsHitConditionalBreakpoints → bool?
The debug adapter supports breakpoints that break execution after a specified number of hits.
final
supportsInstructionBreakpoints → bool?
The debug adapter supports adding breakpoints based on instruction references.
final
supportsLoadedSourcesRequest → bool?
The debug adapter supports the loadedSources request.
final
supportsLogPoints → bool?
The debug adapter supports log points by interpreting the logMessage attribute of the SourceBreakpoint.
final
supportsModulesRequest → bool?
The debug adapter supports the modules request.
final
supportsReadMemoryRequest → bool?
The debug adapter supports the readMemory request.
final
supportsRestartFrame → bool?
The debug adapter supports restarting a frame.
final
supportsRestartRequest → bool?
The debug adapter supports the restart request. In this case a client should not implement restart by terminating and relaunching the adapter but by calling the restart request.
final
supportsSetExpression → bool?
The debug adapter supports the setExpression request.
final
supportsSetVariable → bool?
The debug adapter supports setting a variable to a value.
final
supportsSingleThreadExecutionRequests → bool?
The debug adapter supports the singleThread property on the execution requests (continue, next, stepIn, stepOut, reverseContinue, stepBack).
final
supportsStepBack → bool?
The debug adapter supports stepping back via the stepBack and reverseContinue requests.
final
supportsStepInTargetsRequest → bool?
The debug adapter supports the stepInTargets request.
final
supportsSteppingGranularity → bool?
The debug adapter supports stepping granularities (argument granularity) for the stepping requests.
final
supportsTerminateRequest → bool?
The debug adapter supports the terminate request.
final
supportsTerminateThreadsRequest → bool?
The debug adapter supports the terminateThreads request.
final
supportSuspendDebuggee → bool?
The debug adapter supports the suspendDebuggee attribute on the disconnect request.
final
supportsValueFormattingOptions → bool?
The debug adapter supports a format attribute on the stackTrace, variables, and evaluate requests.
final
supportsWriteMemoryRequest → bool?
The debug adapter supports the writeMemory request.
final
supportTerminateDebuggee → bool?
The debug adapter supports the terminateDebuggee attribute on the disconnect request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → Capabilities