ContinuedEventBody class

Inheritance

Constructors

ContinuedEventBody({bool? allThreadsContinued, required int threadId})
ContinuedEventBody.fromMap(Map<String, Object?> obj)

Properties

allThreadsContinued → bool?
If allThreadsContinued is true, a debug adapter can announce that all threads have continued.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadId → int
The thread which was continued.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → ContinuedEventBody