DapServer class

A DAP server that communicates over a ByteStreamServerChannel, usually constructed from the processes stdin/stdout streams.

The server runs in single-user mode and services only a single client. For multiple debug sessions, there would be multiple servers (and the editor would have a client for each of them).

Constructors

DapServer(Stream<List<int>> input, StreamSink<List<int>> output, {bool ipv6 = false, bool test = false, Logger? logger, Function? onError})

Properties

adapter ↔ DartDebugAdapter<LaunchRequestArguments, AttachRequestArguments>
latefinal
channel → ByteStreamServerChannel
final
hashCode → int
The hash code for this object.
no setterinherited
ipv6 → bool
final
logger → Logger?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
test → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited