toClientPathOrUri method

String? toClientPathOrUri(
  1. Uri? uri
)

Converts a URI into a form that can be used by the client.

Returns null if the uri is not a supported file scheme.

Implementation

String? toClientPathOrUri(Uri? uri) {
  if (uri == null) {
    return null;
  } else if (uri.isScheme('file')) {
    return uri.toFilePath();
  } else {
    return null;
  }
}