DebugAdapterException class

Exception thrown by a debug adapter when a request is not valid, either because the inputs are not correct or the adapter is not in the correct state.

Implemented types

Constructors

DebugAdapterException(String message, {bool showToUser = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToUser → bool
Whether or not to show the error to the user as a notification.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited