DebugAdapterInvalidArgumentException class

Exception thrown when failing to read arguments supplied by the user because they are not the correct type.

This is usually because a user customised their launch configuration (for example in .vscode/launch.json for VS Code) with values that are not valid, such as putting a String in a field intended to be a Map:

    // Bad.
    "env": "foo"

    // Good.
    "env": {
        "FLUTTER_ROOT": "foo",
    }
Implemented types

Constructors

DebugAdapterInvalidArgumentException({required String requestName, required String argumentName, required Type expectedType, required Type actualType, required Object? actualValue, bool showToUser = false})

Properties

actualType → Type
final
actualValue → Object?
final
argumentName → String
final
expectedType → Type
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setteroverride
requestName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showToUser → bool
Whether or not to show the error to the user as a notification.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited