ExceptionBreakpointsFilter class

An ExceptionBreakpointsFilter is shown in the UI as an filter option for configuring how exceptions are dealt with.

Constructors

ExceptionBreakpointsFilter({String? conditionDescription, bool? defaultValue, String? description, required String filter, required String label, bool? supportsCondition})
ExceptionBreakpointsFilter.fromMap(Map<String, Object?> obj)

Properties

conditionDescription → String?
A help text providing information about the condition. This string is shown as the placeholder text for a text box and can be translated.
final
defaultValue → bool?
Initial value of the filter option. If not specified a value false is assumed.
final
description → String?
A help text providing additional information about the exception filter. This string is typically shown as a hover and can be translated.
final
filter → String
The internal ID of the filter option. This value is passed to the setExceptionBreakpoints request.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
The name of the filter option. This is shown in the UI.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsCondition → bool?
Controls whether a condition can be specified for this filter option. If false or missing, a condition can not be set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → ExceptionBreakpointsFilter