ExceptionFilterOptions class

An ExceptionFilterOptions is used to specify an exception filter together with a condition for the setExceptionBreakpoints request.

Constructors

ExceptionFilterOptions({String? condition, required String filterId, String? mode})
ExceptionFilterOptions.fromMap(Map<String, Object?> obj)

Properties

condition → String?
An expression for conditional exceptions. The exception breaks into the debugger if the result of the condition is true.
final
filterId → String
ID of an exception filter returned by the exceptionBreakpointFilters capability.
final
hashCode → int
The hash code for this object.
no setterinherited
mode → String?
The mode of this exception breakpoint. If defined, this must be one of the breakpointModes the debug adapter advertised in its Capabilities.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → ExceptionFilterOptions