FunctionBreakpoint class

Properties of a breakpoint passed to the setFunctionBreakpoints request.

Constructors

FunctionBreakpoint({String? condition, String? hitCondition, required String name})
FunctionBreakpoint.fromMap(Map<String, Object?> obj)

Properties

condition → String?
An expression for conditional breakpoints. It is only honored by a debug adapter if the corresponding capability supportsConditionalBreakpoints is true.
final
hashCode → int
The hash code for this object.
no setterinherited
hitCondition → String?
An expression that controls how many hits of the breakpoint are ignored. The debug adapter is expected to interpret the expression as needed. The attribute is only honored by a debug adapter if the corresponding capability supportsHitConditionalBreakpoints is true.
final
name → String
The name of the function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → FunctionBreakpoint