InitializeRequestArguments class

Arguments for initialize request.

Inheritance

Constructors

InitializeRequestArguments({required String adapterID, String? clientID, String? clientName, bool? columnsStartAt1, bool? linesStartAt1, String? locale, String? pathFormat, bool? supportsANSIStyling, bool? supportsArgsCanBeInterpretedByShell, bool? supportsInvalidatedEvent, bool? supportsMemoryEvent, bool? supportsMemoryReferences, bool? supportsProgressReporting, bool? supportsRunInTerminalRequest, bool? supportsStartDebuggingRequest, bool? supportsVariablePaging, bool? supportsVariableType})
InitializeRequestArguments.fromMap(Map<String, Object?> obj)

Properties

adapterID → String
The ID of the debug adapter.
final
clientID → String?
The ID of the client using this adapter.
final
clientName → String?
The human-readable name of the client using this adapter.
final
columnsStartAt1 → bool?
If true all column numbers are 1-based (default).
final
hashCode → int
The hash code for this object.
no setterinherited
linesStartAt1 → bool?
If true all line numbers are 1-based (default).
final
locale → String?
The ISO-639 locale of the client using this adapter, e.g. en-US or de-CH.
final
pathFormat → String?
Determines in what format paths are specified. The default is path, which is the native format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsANSIStyling → bool?
The client will interpret ANSI escape sequences in the display of OutputEvent.output and Variable.value fields when Capabilities.supportsANSIStyling is also enabled.
final
supportsArgsCanBeInterpretedByShell → bool?
Client supports the argsCanBeInterpretedByShell attribute on the runInTerminal request.
final
supportsInvalidatedEvent → bool?
Client supports the invalidated event.
final
supportsMemoryEvent → bool?
Client supports the memory event.
final
supportsMemoryReferences → bool?
Client supports memory references.
final
supportsProgressReporting → bool?
Client supports progress reporting.
final
supportsRunInTerminalRequest → bool?
Client supports the runInTerminal request.
final
supportsStartDebuggingRequest → bool?
Client supports the startDebugging request.
final
supportsVariablePaging → bool?
Client supports the paging of variables.
final
supportsVariableType → bool?
Client supports the type attribute for variables.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → InitializeRequestArguments