Module class

A Module object represents a row in the modules view. The id attribute identifies a module in the modules view and is used in a module event for identifying a module for adding, updating or deleting. The name attribute is used to minimally render the module in the UI.

Additional attributes can be added to the module. They show up in the module view if they have a corresponding ColumnDescriptor.

To avoid an unnecessary proliferation of additional attributes with similar semantics but different names, we recommend to re-use attributes from the 'recommended' list below first, and only introduce new attributes if nothing appropriate could be found.

Constructors

Module({String? addressRange, String? dateTimeStamp, required Either2<int, String> id, bool? isOptimized, bool? isUserCode, required String name, String? path, String? symbolFilePath, String? symbolStatus, String? version})
Module.fromMap(Map<String, Object?> obj)

Properties

addressRange → String?
Address range covered by this module.
final
dateTimeStamp → String?
Module created or modified, encoded as a RFC 3339 timestamp.
final
hashCode → int
The hash code for this object.
no setterinherited
id → Either2<int, String>
Unique identifier for the module.
final
isOptimized → bool?
True if the module is optimized.
final
isUserCode → bool?
True if the module is considered 'user code' by a debugger that supports 'Just My Code'.
final
name → String
A name of the module.
final
path → String?
Logical full path to the module. The exact definition is implementation defined, but usually this would be a full path to the on-disk file for the module.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolFilePath → String?
Logical full path to the symbol file. The exact definition is implementation defined.
final
symbolStatus → String?
User-understandable description of if symbols were found for the module (ex: 'Symbols Loaded', 'Symbols not found', etc.)
final
version → String?
Version of Module.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → Module