ModulesArguments class

Arguments for modules request.

Inheritance

Constructors

ModulesArguments({int? moduleCount, int? startModule})
ModulesArguments.fromMap(Map<String, Object?> obj)

Properties

hashCode → int
The hash code for this object.
no setterinherited
moduleCount → int?
The number of modules to return. If moduleCount is not specified or 0, all modules are returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startModule → int?
The index of the first module to return; if omitted modules start at 0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → ModulesArguments