ModulesResponseBody class

Constructors

ModulesResponseBody({required List<Module> modules, int? totalModules})
ModulesResponseBody.fromMap(Map<String, Object?> obj)

Properties

hashCode → int
The hash code for this object.
no setterinherited
modules → List<Module>
All modules or range of modules.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalModules → int?
The total number of modules available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → ModulesResponseBody