OutputEventBody class

Inheritance

Constructors

OutputEventBody({String? category, int? column, Object? data, String? group, int? line, int? locationReference, required String output, Source? source, int? variablesReference})
OutputEventBody.fromMap(Map<String, Object?> obj)

Properties

category → String?
The output category. If not specified or if the category is not understood by the client, console is assumed.
final
column → int?
The position in line where the output was produced. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.
final
data → Object?
Additional data to report. For the telemetry category the data is sent to telemetry, for the other categories the data is shown in JSON format.
final
group → String?
Support for keeping an output log organized by grouping related messages.
final
hashCode → int
The hash code for this object.
no setterinherited
line → int?
The source location's line where the output was produced.
final
locationReference → int?
A reference that allows the client to request the location where the new value is declared. For example, if the logged value is function pointer, the adapter may be able to look up the function's location. This should be present only if the adapter is likely to be able to resolve the location.
final
output → String
The output to report.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source?
The source location where the output was produced.
final
variablesReference → int?
If an attribute variablesReference exists and its value is > 0, the output contains objects which can be retrieved by passing variablesReference to the variables request as long as execution remains suspended. See 'Lifetime of Object References' in the Overview section for details.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → OutputEventBody