ProgressUpdateEventBody class

Inheritance

Constructors

ProgressUpdateEventBody({String? message, num? percentage, required String progressId})
ProgressUpdateEventBody.fromMap(Map<String, Object?> obj)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
More detailed progress message. If omitted, the previous message (if any) is used.
final
percentage → num?
Progress percentage to display (value range: 0 to 100). If omitted no percentage is shown.
final
progressId → String
The ID that was introduced in the initial progressStart event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → ProgressUpdateEventBody