RunInTerminalResponseBody class

Constructors

RunInTerminalResponseBody({int? processId, int? shellProcessId})
RunInTerminalResponseBody.fromMap(Map<String, Object?> obj)

Properties

hashCode → int
The hash code for this object.
no setterinherited
processId → int?
The process ID. The value should be less than or equal to 2147483647 (2^31-1).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shellProcessId → int?
The process ID of the terminal shell. The value should be less than or equal to 2147483647 (2^31-1).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → RunInTerminalResponseBody