SetBreakpointsArguments class

Arguments for setBreakpoints request.

Inheritance

Constructors

SetBreakpointsArguments({List<SourceBreakpoint>? breakpoints, List<int>? lines, required Source source, bool? sourceModified})
SetBreakpointsArguments.fromMap(Map<String, Object?> obj)

Properties

breakpoints → List<SourceBreakpoint>?
The code locations of the breakpoints.
final
hashCode → int
The hash code for this object.
no setterinherited
lines → List<int>?
Deprecated: The code locations of the breakpoints.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source
The source location of the breakpoints; either source.path or source.sourceReference must be specified.
final
sourceModified → bool?
A value of true indicates that the underlying source has been modified which results in new breakpoint locations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → SetBreakpointsArguments