SetExceptionBreakpointsArguments class

Arguments for setExceptionBreakpoints request.

Inheritance

Properties

exceptionOptions → List<ExceptionOptions>?
Configuration options for selected exceptions. The attribute is only honored by a debug adapter if the corresponding capability supportsExceptionOptions is true.
final
filterOptions → List<ExceptionFilterOptions>?
Set of exception filters and their options. The set of all possible exception filters is defined by the exceptionBreakpointFilters capability. This attribute is only honored by a debug adapter if the corresponding capability supportsExceptionFilterOptions is true. The filter and filterOptions sets are additive.
final
filters → List<BreakpointModeApplicability>
Set of exception filters specified by their ID. The set of all possible exception filters is defined by the exceptionBreakpointFilters capability. The filter and filterOptions sets are additive.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → SetExceptionBreakpointsArguments