StackTraceArguments class

Arguments for stackTrace request.

Inheritance

Constructors

StackTraceArguments({StackFrameFormat? format, int? levels, int? startFrame, required int threadId})
StackTraceArguments.fromMap(Map<String, Object?> obj)

Properties

format → StackFrameFormat?
Specifies details on how to format the stack frames. The attribute is only honored by a debug adapter if the corresponding capability supportsValueFormattingOptions is true.
final
hashCode → int
The hash code for this object.
no setterinherited
levels → int?
The maximum number of frames to return. If levels is not specified or 0, all frames are returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startFrame → int?
The index of the first frame to return; if omitted frames start at 0.
final
threadId → int
Retrieve the stacktrace for this thread.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → StackTraceArguments