StepInTarget class

A StepInTarget can be used in the stepIn request and determines into which single target the stepIn request should step.

Constructors

StepInTarget({int? column, int? endColumn, int? endLine, required int id, required String label, int? line})
StepInTarget.fromMap(Map<String, Object?> obj)

Properties

column → int?
Start position of the range covered by the step in target. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.
final
endColumn → int?
End position of the range covered by the step in target. It is measured in UTF-16 code units and the client capability columnsStartAt1 determines whether it is 0- or 1-based.
final
endLine → int?
The end line of the range covered by the step-in target.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Unique identifier for a step-in target.
final
label → String
The name of the step-in target (shown in the UI).
final
line → int?
The line of the step-in target.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → StepInTarget