StepInTargetsArguments class

Arguments for stepInTargets request.

Inheritance

Constructors

StepInTargetsArguments({required int frameId})
StepInTargetsArguments.fromMap(Map<String, Object?> obj)

Properties

frameId → int
The stack frame for which to retrieve the possible step-in targets.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → StepInTargetsArguments