StoppedEventBody class

Inheritance

Constructors

StoppedEventBody({bool? allThreadsStopped, String? description, List<int>? hitBreakpointIds, bool? preserveFocusHint, required String reason, String? text, int? threadId})
StoppedEventBody.fromMap(Map<String, Object?> obj)

Properties

allThreadsStopped → bool?
If allThreadsStopped is true, a debug adapter can announce that all threads have stopped.
final
description → String?
The full reason for the event, e.g. 'Paused on exception'. This string is shown in the UI as is and can be translated.
final
hashCode → int
The hash code for this object.
no setterinherited
hitBreakpointIds → List<int>?
Ids of the breakpoints that triggered the event. In most cases there is only a single breakpoint but here are some examples for multiple breakpoints:
final
preserveFocusHint → bool?
A value of true hints to the client that this event should not change the focus.
final
reason → String
The reason for the event. For backward compatibility this string is shown in the UI if the description attribute is missing (but it must not be translated).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Additional information. E.g. if reason is exception, text contains the exception name. This string is shown in the UI.
final
threadId → int?
The thread which was stopped.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → StoppedEventBody