ThreadEventBody class

Inheritance

Constructors

ThreadEventBody({required String reason, required int threadId})
ThreadEventBody.fromMap(Map<String, Object?> obj)

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String
The reason for the event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadId → int
The identifier of the thread.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
override
fromJson(Map<String, Object?> obj) → ThreadEventBody