stopWaitingForVmServiceInfoFile method

void stopWaitingForVmServiceInfoFile()

Stops watching for VM Service Info files that may have been started by waitForVmServiceInfoFile.

This should be called during shutdown in case the VM Service info file was never created.

Implementation

void stopWaitingForVmServiceInfoFile() {
  _vmServiceInfoFileWatcher?.cancel();
}