WriteMemoryResponseBody class

Constructors

WriteMemoryResponseBody({int? bytesWritten, int? offset})
WriteMemoryResponseBody.fromMap(Map<String, Object?> obj)

Properties

bytesWritten → int?
Property that should be returned when allowPartial is true to indicate the number of bytes starting from address that were successfully written.
final
hashCode → int
The hash code for this object.
no setterinherited
offset → int?
Property that should be returned when allowPartial is true to indicate the offset of the first byte of data successfully written. Can be negative.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

canParse(Object? obj) → bool
fromJson(Map<String, Object?> obj) → WriteMemoryResponseBody